@@ -5,7 +5,7 @@ from django.contrib.sites.models import Site
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseNotAllowed, HttpResponseBadRequest
 from django.views.decorators.http import require_POST
-from ebaysuds.service import EbaySuds
+from ebaysuds import EbaySuds
 from suds.plugin import PluginContainer
 
 from . import NOTIFICATION_PAYLOADS
